@@ -209,6 +209,7 @@ const Embed = new Lang.Class({
     _init: function() {
         this._queryErrorId = 0;
         this._noResultsChangeId = 0;
+        this._loadShowId = 0;
 
         this.widget = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL,
                                     visible: true });
@@ -217,7 +218,8 @@ const Embed = new Lang.Class({
         this.widget.pack_end(this._stackOverlay, true, true, 0);
 
         this._stack = new Gd.Stack({ visible: true,
-                                     homogeneous: true });
+                                     homogeneous: true,
+                                     transition_type: Gd.StackTransitionType.CROSSFADE });
         this._stackOverlay.add(this._stack);
 
         // create the OSD toolbar for selected items, it's hidden by default
@@ -443,8 +445,10 @@ const Embed = new Lang.Class({
     },
 
     getMainToolbar: function() {
+        let windowMode = Application.modeController.getWindowMode();
         let fullscreen = Application.modeController.getFullscreen();
-        if (fullscreen)
+
+        if (fullscreen && (windowMode == WindowMode.WindowMode.PREVIEW))
             return this._preview.getFullscreenToolbar();
         else
             return this._toolbar;
