@@ -76,6 +76,8 @@ const MainWindow = new Lang.Class({
 
         this.window.connect('delete-event',
                             Lang.bind(this, this._quit));
+        this.window.connect('button-press-event',
+                            Lang.bind(this, this._onButtonPressEvent));
         this.window.connect('key-press-event',
                             Lang.bind(this, this._onKeyPressEvent));
         this.window.connect('configure-event',
@@ -141,12 +143,46 @@ const MainWindow = new Lang.Class({
             this.window.unfullscreen();
     },
 
+    _goBack: function() {
+        let windowMode = Application.modeController.getWindowMode();
+        let activeCollection = Application.collectionManager.getActiveItem();
+        let handled = true;
+
+        if (windowMode == WindowMode.WindowMode.PREVIEW ||
+            windowMode == WindowMode.WindowMode.EDIT) {
+            Application.documentManager.setActiveItem(null);
+        } else if (windowMode == WindowMode.WindowMode.OVERVIEW && activeCollection) {
+            Application.documentManager.activatePreviousCollection();
+        } else {
+            handled = false;
+        }
+
+        return handled;
+    },
+
+    _onButtonPressEvent: function(widget, event) {
+        let button = event.get_button()[1];
+        let clickCount = event.get_click_count()[1];
+
+        if (clickCount > 1)
+            return false;
+
+        // mouse back button
+        if (button != 8)
+            return false;
+
+        return this._goBack();
+    },
+
     _onKeyPressEvent: function(widget, event) {
         let toolbar = this._embed.getMainToolbar();
 
         if (toolbar.handleEvent(event))
             return true;
 
+        if (this._handleBackKey(event))
+            return true;
+
         switch (Application.modeController.getWindowMode()) {
         case WindowMode.WindowMode.NONE:
             return false;
@@ -164,11 +200,30 @@ const MainWindow = new Lang.Class({
         return false;
     },
 
-    _handleKeyPreview: function(event) {
+    _isBackKey: function(event) {
+        let direction = this.window.get_direction();
         let keyval = event.get_keyval()[1];
         let state = event.get_state()[1];
+
+        let isBack = (((state & Gdk.ModifierType.MOD1_MASK) != 0 &&
+                       (direction == Gtk.TextDirection.LTR && keyval == Gdk.KEY_Left) ||
+                       (direction == Gtk.TextDirection.RTL && keyval == Gdk.KEY_Right)) ||
+                      keyval == Gdk.KEY_Back);
+
+        return isBack;
+    },
+
+    _handleBackKey: function(event) {
+        let isBack = this._isBackKey(event);
+        if (!isBack)
+            return false;
+
+        return this._goBack();
+    },
+
+    _handleKeyPreview: function(event) {
+        let keyval = event.get_keyval()[1];
         let fullscreen = Application.modeController.getFullscreen();
-        let direction = this.window.get_direction();
 
         if (keyval == Gdk.KEY_Escape) {
             let preview = this._embed.getPreview();
@@ -178,16 +233,6 @@ const MainWindow = new Lang.Class({
                 preview.controlsVisible = false;
             else if (fullscreen)
                 Application.documentManager.setActiveItem(null);
-
-            return false;
-        }
-
-        if (((state & Gdk.ModifierType.MOD1_MASK) != 0 &&
-             (direction == Gtk.TextDirection.LTR && keyval == Gdk.KEY_Left) ||
-             (direction == Gtk.TextDirection.RTL && keyval == Gdk.KEY_Right)) ||
-            keyval == Gdk.KEY_Back) {
-            Application.documentManager.setActiveItem(null);
-            return true;
         }
 
         return false;
